@@ -6,7 +6,7 @@
 * This file is part of the Prelude-LML program.
 *
 * This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by 
+* it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
@@ -48,7 +48,7 @@ struct pcre_plugin {
         char *rulesetdir;
         int last_rules_first;
         prelude_bool_t dump_unmatched;
-        
+
         prelude_list_t rule_list;
         prelude_list_t context_list;
 };
@@ -57,11 +57,11 @@ struct pcre_plugin {
 
 struct pcre_context {
         prelude_list_t list;
-        
+
         char *name;
         prelude_timer_t timer;
         pcre_context_setting_t *setting;
-        
+
         idmef_message_t *idmef;
 };
 
@@ -79,12 +79,12 @@ static lml_log_plugin_t pcre_plugin;
 
 
 
-static int parse_key_and_value(char *input, char **key, char **value) 
+static int parse_key_and_value(char *input, char **key, char **value)
 {
         char *ptr, *tmp;
 
         *value = NULL;
-        
+
         /*
          * filter space at the begining of the line.
          */
@@ -93,7 +93,7 @@ static int parse_key_and_value(char *input, char **key, char **value)
 
         if ( *input == '\0' )
                 return 0;
-        
+
         *key = input;
 
         /*
@@ -101,7 +101,7 @@ static int parse_key_and_value(char *input, char **key, char **value)
          * corresponding to the key = value separator.
          */
         tmp = ptr = input + strcspn(input, "=:");
-        
+
         /*
          * strip whitespace at the tail of the key.
          */
@@ -110,8 +110,8 @@ static int parse_key_and_value(char *input, char **key, char **value)
 
         if ( ! ptr )
                 /* key without value */
-                return 0; 
-        
+                return 0;
+
         /*
          * strip whitespace at the begining of the value.
          */
@@ -130,7 +130,7 @@ static int parse_key_and_value(char *input, char **key, char **value)
 
         if ( *ptr == ';' )
                 *ptr = 0;
-        
+
         return 0;
 }
 
@@ -143,7 +143,7 @@ static int parse_multiple_key_and_value(const char **input, char **key, char **v
         union { char **rw; const char **ro; } val;
 
         val.ro = input;
-        
+
         ptr = strsep(val.rw, ",");
         if ( ! ptr )
                 return 0;
@@ -165,16 +165,16 @@ static pcre_rule_container_t *create_rule_container(pcre_rule_t *rule)
                 prelude_log(PRELUDE_LOG_ERR, "memory exhausted.\n");
                 return NULL;
         }
-        
+
         rc->rule = rule;
         rule->refcount++;
-        
+
         return rc;
 }
 
 
 
-static int parse_rule_id(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *id) 
+static int parse_rule_id(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *id)
 {
         rule->id = (unsigned int) strtoul(id, NULL, 0);
 
@@ -183,7 +183,7 @@ static int parse_rule_id(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *i
 
 
 
-static int parse_rule_revision(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *revision) 
+static int parse_rule_revision(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *revision)
 {
         rule->revision = (unsigned int) strtoul(revision, NULL, 0);
 
@@ -192,22 +192,22 @@ static int parse_rule_revision(pcre_plugin_t *plugin, pcre_rule_t *rule, const c
 
 
 
-static int parse_rule_regex(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *regex) 
+static int parse_rule_regex(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *regex)
 {
         rule_regex_t *new;
 
         new = rule_regex_new(regex, FALSE);
         if ( ! new )
                 return -1;
-        
+
         prelude_linked_object_add_tail(&rule->regex_list, (prelude_linked_object_t *) new);
-        
+
         return 0;
 }
 
 
 
-static int parse_rule_optregex(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *regex) 
+static int parse_rule_optregex(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *regex)
 {
         rule_regex_t *new;
 
@@ -216,7 +216,7 @@ static int parse_rule_optregex(pcre_plugin_t *plugin, pcre_rule_t *rule, const c
                 return -1;
 
         prelude_linked_object_add_tail(&rule->regex_list, (prelude_linked_object_t *) new);
-        
+
         return 0;
 }
 
@@ -226,13 +226,13 @@ static pcre_rule_container_t *search_rule(prelude_list_t *head, int id)
 {
         prelude_list_t *tmp;
         pcre_rule_container_t *cur;
-        
+
         prelude_list_for_each(head, tmp) {
                 cur = prelude_list_entry(tmp, pcre_rule_container_t, list);
-                
+
                 if ( cur->rule->id == id )
                         return cur;
-                
+
                 cur = search_rule(&cur->rule->rule_list, id);
                 if ( cur )
                         return cur;
@@ -255,14 +255,14 @@ static int add_goto_single(pcre_plugin_t *plugin, pcre_rule_t *rule, int id, pre
                         return -1;
                 }
         }
-        
+
         new = create_rule_container(cur->rule);
-        if ( ! new ) 
+        if ( ! new )
                 return -1;
 
         if ( optional )
                 new->optional = TRUE;
-                
+
         prelude_list_add_tail(&rule->rule_list, &new->list);
 
         return 0;
@@ -272,7 +272,7 @@ static int add_goto_single(pcre_plugin_t *plugin, pcre_rule_t *rule, int id, pre
 static int add_goto(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *idstr, prelude_bool_t optional)
 {
         int ret, i, idmin = 0, idmax = 0;
-        
+
         ret = sscanf(idstr, "%d-%d", &idmin, &idmax);
         if ( ret < 1 ) {
                 prelude_log(PRELUDE_LOG_WARN, "could not parse goto value '%s'.\n", idstr);
@@ -281,9 +281,9 @@ static int add_goto(pcre_plugin_t *plugin, pcre_rule_t *rule, const char *idstr,
 
         if ( ret == 1 )
                 idmax = idmin;
-                
+
         for ( i = idmin; i <= idmax; i++ ) {
-                
+
                 ret = add_goto_single(plugin, rule, i, optional);
                 if ( ret < 0 )
                         return -1;
@@ -385,7 +385,7 @@ static int _parse_create_context(pcre_rule_t *rule, const char *arg, pcre_contex
         char *key, *value;
         const char *cname = NULL;
         pcre_context_setting_t *pcs;
-        
+
         pcs = calloc(1, sizeof(*pcs));
         if ( ! pcs )
                 return -1;
@@ -393,20 +393,20 @@ static int _parse_create_context(pcre_rule_t *rule, const char *arg, pcre_contex
         pcs->timeout = 60;
         pcs->flags = flags;
 
-        while ( (ret = parse_multiple_key_and_value(&arg, &key, &value)) == 1 ) {                
-                
+        while ( (ret = parse_multiple_key_and_value(&arg, &key, &value)) == 1 ) {
+
                 if ( ! cname )
                         cname = key;
-                
+
                 else if ( strcmp(key, "alert_on_destroy") == 0 )
                         pcs->flags |= PCRE_CONTEXT_SETTING_FLAGS_ALERT_ON_DESTROY;
-                
+
                 else if ( strcmp(key, "alert_on_expire") == 0 )
                         pcs->flags |= PCRE_CONTEXT_SETTING_FLAGS_ALERT_ON_EXPIRE;
-                
+
                 else if ( strcmp(key, "expire") == 0 )
                         pcs->timeout = atoi(value);
-                
+
                 else {
                         free(pcs);
                         prelude_log(PRELUDE_LOG_WARN, "Unknown context creation argument: '%s'.\n", key);
@@ -419,7 +419,7 @@ static int _parse_create_context(pcre_rule_t *rule, const char *arg, pcre_contex
 
         if ( ret < 0 )
                 free(pcs);
-        
+
         return ret;
 }
 
@@ -446,7 +446,7 @@ static int parse_not_context(pcre_plugin_t *plugin, pcre_rule_t *rule, const cha
 {
         int ret;
         value_container_t *vcont;
-        
+
         ret = value_container_new(&vcont, arg);
         if ( ret < 0 )
                 return ret;
@@ -464,7 +464,7 @@ static int parse_destroy_context(pcre_plugin_t *plugin, pcre_rule_t *rule, const
 
 
 
-static int parse_include(pcre_rule_t *rule, pcre_plugin_t *plugin, const char *value) 
+static int parse_include(pcre_rule_t *rule, pcre_plugin_t *plugin, const char *value)
 {
         int ret;
         FILE *fd;
@@ -480,7 +480,7 @@ static int parse_include(pcre_rule_t *rule, pcre_plugin_t *plugin, const char *v
                 prelude_log(PRELUDE_LOG_ERR, "couldn't open %s for reading: %s.\n", filename, strerror(errno));
                 return -1;
         }
-        
+
         ret = parse_ruleset(rule ? &rule->rule_list : &plugin->rule_list, plugin, filename, fd);
 
         fclose(fd);
@@ -490,7 +490,7 @@ static int parse_include(pcre_rule_t *rule, pcre_plugin_t *plugin, const char *v
 
 
 
-static char *cut_line(char *buf, char **sptr) 
+static char *cut_line(char *buf, char **sptr)
 {
         int escaped = 0;
         char *ptr, *wptr;
@@ -502,7 +502,7 @@ static char *cut_line(char *buf, char **sptr)
         *sptr = NULL;
 
         while ( *ptr ) {
-                if ( *ptr == '\\' ) 
+                if ( *ptr == '\\' )
                         escaped = 1;
 
                 else if ( ! escaped && *ptr == ';' ) {
@@ -517,7 +517,7 @@ static char *cut_line(char *buf, char **sptr)
 
                         escaped = 0;
                 }
-                
+
                 *wptr++ = *ptr++;
         }
 
@@ -531,23 +531,23 @@ static int parse_rule_included(pcre_plugin_t *plugin, pcre_rule_t *rule, const c
         int ret;
         prelude_list_t *t;
         pcre_rule_container_t tmp, *cur;
-        
+
         rule->flags |= PCRE_RULE_FLAGS_SILENT;
-        
+
         tmp.rule = rule;
         prelude_list_add(&plugin->rule_list, &tmp.list);
-        
+
         ret = parse_include(rule, plugin, value);
         prelude_list_del(&tmp.list);
-        
+
         prelude_list_for_each(&rule->rule_list, t) {
                 cur = prelude_list_entry(t, pcre_rule_container_t, list);
                 cur->optional = 1;
         }
-        
+
         return ret;
 }
-        
+
 
 static int parse_rule_keyword(pcre_plugin_t *plugin, pcre_rule_t *rule,
                               const char *filename, int line,
@@ -578,7 +578,7 @@ static int parse_rule_keyword(pcre_plugin_t *plugin, pcre_rule_t *rule,
                 { "require_context"     , parse_require_context         },
                 { "optional_context"    , parse_optional_context        }
         };
-        
+
         for ( i = 0; i < sizeof(keywords) / sizeof(keywords[0]); i++ ) {
                 if ( strcmp(keyword, keywords[i].keyword) != 0 )
                         continue;
@@ -613,7 +613,7 @@ static int parse_rule_entry(pcre_plugin_t *plugin, pcre_rule_t *rule,
         /*
          * ... or an idmef object
          */
-        return rule_object_add(rule->object_list, filename, line, key, value);        
+        return rule_object_add(rule->object_list, filename, line, key, value);
 }
 
 
@@ -633,36 +633,36 @@ static pcre_rule_t *create_rule(void)
                 free(rule);
                 return NULL;
         }
-        
+
         prelude_list_init(&rule->rule_list);
         prelude_list_init(&rule->regex_list);
         prelude_list_init(&rule->not_context_list);
         prelude_list_init(&rule->create_context_list);
         prelude_list_init(&rule->destroy_context_list);
-                
+
         return rule;
 }
 
 
 
-static void free_rule(pcre_rule_t *rule) 
+static void free_rule(pcre_rule_t *rule)
 {
         rule_regex_t *item;
         prelude_list_t *tmp, *bkp;
         pcre_rule_container_t *rc;
-        
+
         prelude_list_for_each_safe(&rule->rule_list, tmp, bkp) {
                 rc = prelude_list_entry(tmp, pcre_rule_container_t, list);
                 free_rule_container(rc);
         }
-        
+
         prelude_list_for_each_safe(&rule->regex_list, tmp, bkp) {
                 item = prelude_linked_object_get_object(tmp);
                 rule_regex_destroy(item);
         }
 
         rule_object_list_destroy(rule->object_list);
-                                        
+
         free(rule);
 }
 
@@ -672,14 +672,14 @@ static void free_rule_container(pcre_rule_container_t *rc)
 {
         if ( --rc->rule->refcount == 0 )
                 free_rule(rc->rule);
-        
+
         prelude_list_del(&rc->list);
         free(rc);
 }
 
 
 
-static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin, const char *filename, int line, char *buf) 
+static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin, const char *filename, int line, char *buf)
 {
         char *in;
         char *key;
@@ -688,10 +688,10 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
         int first_directive = 1;
         pcre_rule_t *rule = NULL;
         pcre_rule_container_t *rc = NULL;
-                
+
         while ( (in = cut_line(buf, &ptr)) ) {
                 buf = NULL;
-                
+
                 /*
                  * filter space at the begining of the line.
                  */
@@ -699,7 +699,7 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
                         in++;
 
                 /*
-                 * empty line or comment. 
+                 * empty line or comment.
                  */
                 if ( *in == '\0' || *in == '\n' || *in == '#' )
                         continue;
@@ -708,23 +708,23 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
                         prelude_log(PRELUDE_LOG_WARN, "%s:%d: no string delimiter.\n", filename, line);
                         return -1;
                 }
-                
+
                 if ( first_directive ) {
                         if ( strcmp(key, "include") == 0 ) {
                                 parse_include(NULL, plugin, value);
                                 return 0;
                         }
-                        
+
                         rule = create_rule();
                         if ( ! rule )
                                 return -1;
-                        
+
                         /*
                          * hack so that the rule is reachable.
                          */
                         first_directive = 0;
                 }
-                
+
                 if ( parse_rule_entry(plugin, rule, filename, line, key, value) < 0 ) {
                         free_rule(rule);
                         return -1;
@@ -745,12 +745,12 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
 
         if ( rule->flags & PCRE_RULE_FLAGS_CHAINED )
                 prelude_list_add(&chained_rule_list, &rc->list);
-        
+
         else if ( plugin->last_rules_first && rule->flags & PCRE_RULE_FLAGS_LAST )
                 prelude_list_add(head, &rc->list);
         else
                 prelude_list_add_tail(head, &rc->list);
-        
+
         plugin->rulesnum++;
 
         return 0;
@@ -758,24 +758,24 @@ static int parse_ruleset_directive(prelude_list_t *head, pcre_plugin_t *plugin,
 
 
 
-static int parse_ruleset(prelude_list_t *head, pcre_plugin_t *plugin, const char *filename, FILE *fd) 
+static int parse_ruleset(prelude_list_t *head, pcre_plugin_t *plugin, const char *filename, FILE *fd)
 {
         char buf[8192], *ptr;
         unsigned int line = 0;
-        
+
         while ( prelude_read_multiline(fd, &line, buf, sizeof(buf)) == 0 ) {
-                
+
                 ptr = buf + strlen(buf) - 1;
                 if ( *ptr == '\n' )
                         *ptr = '\0'; /* strip \n */
-                
+
                 /*
                  * filter space and tab at the begining of the line.
                  */
                 for ( ptr = buf; (*ptr == ' ' || *ptr == '\t') && *ptr != '\0'; ptr++ );
 
                 /*
-                 * empty line or comment. 
+                 * empty line or comment.
                  */
                 if ( *ptr == '\0' || *ptr == '#' )
                         continue;
@@ -795,9 +795,9 @@ static void pcre_run(prelude_plugin_instance_t *pi, const lml_log_source_t *ls,
         pcre_plugin_t *plugin;
         pcre_rule_container_t *rc;
         pcre_match_flags_t flags, all_flags = 0;
-        
+
         prelude_log_debug(10, "\nInput = %s\n", lml_log_entry_get_message(log_entry));
-        
+
         plugin = prelude_plugin_instance_get_plugin_data(pi);
 
         prelude_list_for_each(&plugin->rule_list, tmp) {
@@ -806,7 +806,7 @@ static void pcre_run(prelude_plugin_instance_t *pi, const lml_log_source_t *ls,
                 flags = 0;
                 ret = rule_regex_match(plugin, rc, ls, log_entry, &flags);
                 all_flags |= flags;
-                
+
                 if ( ret == 0 && (rc->rule->flags & PCRE_RULE_FLAGS_LAST || flags & PCRE_MATCH_FLAGS_LAST) )
                         break;
         }
@@ -822,9 +822,9 @@ static void pcre_run(prelude_plugin_instance_t *pi, const lml_log_source_t *ls,
 static int set_last_first(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         pcre_plugin_t *plugin = prelude_plugin_instance_get_plugin_data(context);
-        
+
         plugin->last_rules_first = TRUE;
-        
+
         return 0;
 }
 
@@ -832,9 +832,9 @@ static int set_last_first(prelude_option_t *opt, const char *optarg, prelude_str
 static int set_dump_unmatched(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         pcre_plugin_t *plugin = prelude_plugin_instance_get_plugin_data(context);
-        
+
         plugin->dump_unmatched = TRUE;
-        
+
         return 0;
 }
 
@@ -843,7 +843,7 @@ static void remove_top_chained(void)
 {
         prelude_list_t *tmp, *bkp;
         pcre_rule_container_t *rc;
-        
+
         prelude_list_for_each_safe(&chained_rule_list, tmp, bkp) {
                 rc = prelude_list_entry(tmp, pcre_rule_container_t, list);
 
@@ -854,13 +854,13 @@ static void remove_top_chained(void)
 
 
 
-static int set_pcre_ruleset(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context) 
+static int set_pcre_ruleset(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         int ret;
         FILE *fd;
         char *ptr;
         pcre_plugin_t *plugin = prelude_plugin_instance_get_plugin_data(context);
-        
+
         plugin->rulesetdir = strdup(optarg);
 
         ptr = strrchr(plugin->rulesetdir, '/');
@@ -870,7 +870,7 @@ static int set_pcre_ruleset(prelude_option_t *opt, const char *optarg, prelude_s
                 free(plugin->rulesetdir);
                 plugin->rulesetdir = NULL;
         }
-        
+
         fd = fopen(optarg, "r");
         if ( ! fd ) {
                 prelude_string_sprintf(err, "couldn't open %s for reading: %s", optarg, strerror(errno));
@@ -882,14 +882,14 @@ static int set_pcre_ruleset(prelude_option_t *opt, const char *optarg, prelude_s
         fclose(fd);
         if ( plugin->rulesetdir )
                 free(plugin->rulesetdir);
-        
+
         if ( ret < 0 )
                 return -1;
 
-        prelude_log(PRELUDE_LOG_INFO, "- pcre plugin loaded %d rules.\n", plugin->rulesnum);
+        prelude_log(PRELUDE_LOG_INFO, "PCRE plugin loaded %d rules.\n", plugin->rulesnum);
 
         remove_top_chained();
-        
+
         return 0;
 }
 
@@ -898,16 +898,16 @@ static int set_pcre_ruleset(prelude_option_t *opt, const char *optarg, prelude_s
 static int pcre_activate(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         pcre_plugin_t *new;
-        
+
         new = calloc(1, sizeof(*new));
         if ( ! new )
                 return prelude_error_from_errno(errno);
 
         prelude_list_init(&new->rule_list);
         prelude_list_init(&new->context_list);
-        
+
         prelude_plugin_instance_set_plugin_data(context, new);
-        
+
         return 0;
 }
 
@@ -919,23 +919,23 @@ static void pcre_destroy(prelude_plugin_instance_t *pi, prelude_string_t *err)
         prelude_list_t *tmp, *bkp;
         pcre_rule_container_t *rule;
         pcre_plugin_t *plugin = prelude_plugin_instance_get_plugin_data(pi);
-        
+
         prelude_list_for_each_safe(&plugin->rule_list, tmp, bkp) {
                 rule = prelude_list_entry(tmp, pcre_rule_container_t, list);
                 free_rule_container(rule);
         }
-        
+
         free(plugin);
 }
 
 
 static void _pcre_context_destroy(pcre_context_t *ctx)
-{        
+{
         prelude_log_debug(1, "[%s]: destroying context.\n", ctx->name);
-        
+
         if ( ctx->idmef )
                 idmef_message_destroy(ctx->idmef);
-        
+
         prelude_timer_destroy(&ctx->timer);
         prelude_list_del(&ctx->list);
 
@@ -946,12 +946,12 @@ static void _pcre_context_destroy(pcre_context_t *ctx)
 
 
 void pcre_context_destroy(pcre_context_t *ctx)
-{        
+{
         if ( ctx->setting->flags & PCRE_CONTEXT_SETTING_FLAGS_ALERT_ON_DESTROY && ctx->idmef ) {
                 prelude_log_debug(1, "[%s]: emit alert on destroy.\n", ctx->name);
                 lml_alert_emit(NULL, NULL, ctx->idmef);
         }
-        
+
         _pcre_context_destroy(ctx);
 }
 
@@ -960,12 +960,12 @@ void pcre_context_destroy(pcre_context_t *ctx)
 static void pcre_context_expire(void *data)
 {
         pcre_context_t *ctx = data;
-        
+
         if ( ctx->setting->flags & PCRE_CONTEXT_SETTING_FLAGS_ALERT_ON_EXPIRE && ctx->idmef ) {
                 prelude_log_debug(1, "[%s]: emit alert on expire.\n", ctx->name);
                 lml_alert_emit(NULL, NULL, ctx->idmef);
         }
-        
+
         _pcre_context_destroy(ctx);
 }
 
@@ -994,9 +994,9 @@ int pcre_context_new(pcre_plugin_t *plugin, const char *name, idmef_message_t *i
                         }
                 }
         }
-        
+
         prelude_log_debug(1, "[%s]: creating context (expire=%ds).\n", name, setting->timeout);
-        
+
         ctx = calloc(1, sizeof(*ctx));
         if ( ! ctx ) {
                 prelude_log(PRELUDE_LOG_ERR, "memory exhausted.\n");
@@ -1012,7 +1012,7 @@ int pcre_context_new(pcre_plugin_t *plugin, const char *name, idmef_message_t *i
 
         ctx->setting = setting;
         prelude_timer_init_list(&ctx->timer);
-                
+
         if ( setting->timeout > 0 ) {
                 prelude_timer_set_data(&ctx->timer, ctx);
                 prelude_timer_set_expire(&ctx->timer, setting->timeout);
@@ -1022,9 +1022,9 @@ int pcre_context_new(pcre_plugin_t *plugin, const char *name, idmef_message_t *i
 
         if ( idmef )
                 ctx->idmef = idmef_message_ref(idmef);
-        
+
         prelude_list_add_tail(&plugin->context_list, &ctx->list);
-        
+
         return 0;
 }
 
@@ -1041,7 +1041,7 @@ pcre_context_t *pcre_context_search(pcre_plugin_t *plugin, const char *name)
                 if ( strcmp(ctx->name, name) == 0 )
                         return ctx;
         }
-        
+
         return NULL;
 }
 
@@ -1052,19 +1052,19 @@ int pcre_LTX_lml_plugin_init(prelude_plugin_entry_t *pe, void *lml_root_optlist)
         int ret;
         prelude_option_t *opt, *popt;
         int hook = PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG;
-        
+
         ret = prelude_option_add(lml_root_optlist, &opt, hook, 0, "pcre", "Pcre plugin option",
                                  PRELUDE_OPTION_ARGUMENT_OPTIONAL, pcre_activate, NULL);
         if ( ret < 0 )
                 return ret;
-        
+
         prelude_plugin_set_activation_option(pe, opt, NULL);
-        
+
         ret = prelude_option_add(opt, NULL, hook, 'r', "ruleset", "Ruleset to use",
                                  PRELUDE_OPTION_ARGUMENT_REQUIRED, set_pcre_ruleset, NULL);
         if ( ret < 0 )
                 return ret;
-        
+
         ret = prelude_option_add(opt, &popt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'l',
                                  "last-first", "Process rules with the \"last\" attribute first",
                                  PRELUDE_OPTION_ARGUMENT_NONE, set_last_first, NULL);
@@ -1081,9 +1081,9 @@ int pcre_LTX_lml_plugin_init(prelude_plugin_entry_t *pe, void *lml_root_optlist)
         pcre_plugin.run = pcre_run;
         prelude_plugin_set_name(&pcre_plugin, "pcre");
         prelude_plugin_set_destroy_func(&pcre_plugin, pcre_destroy);
-        
+
         prelude_plugin_entry_set_plugin(pe, (void *) &pcre_plugin);
-        
+
         return 0;
 }
 
