@@ -6,7 +6,7 @@
 * This file is part of the Prelude-LML program.
 *
 * This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by 
+* it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
@@ -75,10 +75,10 @@ static int drop_privilege(void)
                 if ( ret < 0 ) {
                         prelude_log(PRELUDE_LOG_ERR, "removal of ancillary groups failed: %s.\n", strerror(errno));
                         return ret;
-                }                
+                }
         }
 
-        
+
         if ( config.wanted_uid != getuid() ) {
                 ret = setuid(config.wanted_uid);
                 if ( ret < 0 ) {
@@ -87,7 +87,7 @@ static int drop_privilege(void)
                         return ret;
                 }
         }
-        
+
         return 0;
 }
 
@@ -139,7 +139,7 @@ static int set_no_resolve(prelude_option_t *opt, const char *optarg, prelude_str
 }
 
 
-static int set_rotation_time_offset(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context) 
+static int set_rotation_time_offset(prelude_option_t *opt, const char *optarg, prelude_string_t *err, void *context)
 {
         char *endptr;
         unsigned long int off;
@@ -149,7 +149,7 @@ static int set_rotation_time_offset(prelude_option_t *opt, const char *optarg, p
                 prelude_string_sprintf(err, "Invalid max rotation time offset specified: %s", optarg);
                 return -1;
         }
-        
+
         file_server_set_max_rotation_time_offset(off);
         return 0;
 }
@@ -162,7 +162,7 @@ static int get_rotation_time_offset(prelude_option_t *opt, prelude_string_t *out
 }
 
 
-static int set_rotation_size_offset(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context) 
+static int set_rotation_size_offset(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
 {
         char *endptr;
         unsigned long int off;
@@ -172,7 +172,7 @@ static int set_rotation_size_offset(prelude_option_t *opt, const char *arg, prel
                 prelude_string_sprintf(err, "Invalid max rotation size offset specified: %s", arg);
                 return -1;
         }
-        
+
         file_server_set_max_rotation_size_offset(off);
         return 0;
 }
@@ -205,9 +205,9 @@ static int set_daemon_mode(prelude_option_t *opt, const char *optarg, prelude_st
         prelude_daemonize(config.pidfile);
         if ( config.pidfile )
                 free(config.pidfile);
-        
+
         prelude_log_set_flags(prelude_log_get_flags()|PRELUDE_LOG_FLAGS_QUIET|PRELUDE_LOG_FLAGS_SYSLOG);
-        
+
         return 0;
 }
 
@@ -217,7 +217,7 @@ static int set_pidfile(prelude_option_t *opt, const char *arg, prelude_string_t
         config.pidfile = strdup(arg);
         if ( ! config.pidfile )
                 return prelude_error_from_errno(errno);
-        
+
         return 0;
 }
 
@@ -248,11 +248,11 @@ static int set_text_output(prelude_option_t *opt, const char *arg, prelude_strin
 {
         int ret;
         FILE *fd;
-        
+
         ret = prelude_io_new(&(config.text_output_fd));
         if ( ret < 0 )
                 return ret;
-        
+
         if ( ! arg || strcmp(arg, "-") == 0 ) {
                 prelude_io_set_file_io(config.text_output_fd, stdout);
                 return 0;
@@ -279,8 +279,8 @@ static int check_file_access(const char *filename)
         ret = stat(filename, &st);
         if ( ret < 0 ) {
                 if ( errno == ENOENT )
-                        prelude_log(PRELUDE_LOG_WARN, "* WARNING: %s does not exist.\n", filename);
-                
+                        prelude_log(PRELUDE_LOG_WARN, "%s does not exist.\n", filename);
+
                 else if ( errno == EACCES )
                         goto out;
 
@@ -291,7 +291,7 @@ static int check_file_access(const char *filename)
 
         if ( config.wanted_uid == 0 )
                 return 0;
-        
+
         if ( st.st_uid == config.wanted_uid && st.st_mode & S_IRUSR )
                 return 0;
 
@@ -302,7 +302,7 @@ static int check_file_access(const char *filename)
                 return 0;
 
  out:
-        prelude_log(PRELUDE_LOG_WARN, "* WARNING: %s is not available for reading to uid %d/gid %d.\n",
+        prelude_log(PRELUDE_LOG_WARN, "%s is not available for reading to uid %d/gid %d.\n",
                     filename, config.wanted_uid, config.wanted_gid);
 
         return -1;
@@ -311,7 +311,7 @@ static int check_file_access(const char *filename)
 
 static int glob_errfunc_cb(const char *epath, int eerrno)
 {
-        prelude_log(PRELUDE_LOG_WARN, "* WARNING: error with '%s': %s.\n", epath, strerror(eerrno));
+        prelude_log(PRELUDE_LOG_WARN, "error with '%s': %s.\n", epath, strerror(eerrno));
         return 0;
 }
 
@@ -322,39 +322,39 @@ static int get_file_from_pattern(void *context, const char *pattern)
         size_t i;
         glob_t gl;
         lml_log_source_t *ls;
-        
+
         ret = glob(pattern, GLOB_NOCHECK | GLOB_TILDE, glob_errfunc_cb, &gl);
         if ( ret != 0 ) {
                 prelude_log(PRELUDE_LOG_ERR, "glob failed: %s.\n", strerror(errno));
-                return ret; 
+                return ret;
         }
-        
+
         for ( i = 0; i < gl.gl_pathc; i++ ) {
                 ret = check_file_access(gl.gl_pathv[i]);
                 if ( ret < 0 )
                         continue; /* ignore error */
-        
+
                 ret = lml_log_source_new(&ls, context, gl.gl_pathv[i]);
                 if ( ret < 0 )
                         break;
-                
-                else if ( ret == 1 ) 
+
+                else if ( ret == 1 )
                         continue;
-                
+
                 ret = file_server_monitor_file(ls);
                 if ( ret < 0 )
                         break;
-                
+
                 have_file = TRUE;
         }
-        
+
         globfree(&gl);
-        
+
         return ret;
 }
 
 
-static int set_file(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context) 
+static int set_file(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
 {
         int ret;
         lml_log_source_t *ls;
@@ -368,16 +368,16 @@ static int set_file(prelude_option_t *opt, const char *arg, prelude_string_t *er
                 if ( ret < 0 )
                         return prelude_error_from_errno(errno);
 
-                if ( ret == 1 ) 
+                if ( ret == 1 )
                         return 0;
-                
+
                 ret = file_server_monitor_file(ls);
-                if ( ret < 0 ) 
+                if ( ret < 0 )
                         return ret;
-        
+
                 have_file = TRUE;
         }
-                
+
         return 0;
 }
 
@@ -387,27 +387,27 @@ static int add_server(lml_log_source_t *ls, const char *addr, unsigned int port)
 {
         config.udp_nserver++;
 
-        config.udp_server = _prelude_realloc(config.udp_server, sizeof(*config.udp_server) * config.udp_nserver);        
+        config.udp_server = _prelude_realloc(config.udp_server, sizeof(*config.udp_server) * config.udp_nserver);
         if ( ! config.udp_server )
                 return -1;
-        
-        config.udp_server[config.udp_nserver - 1] = udp_server_new(ls, addr, port);        
+
+        config.udp_server[config.udp_nserver - 1] = udp_server_new(ls, addr, port);
         if ( ! config.udp_server[config.udp_nserver - 1] )
                 return -1;
-                
+
         return 0;
 }
 
 
 
-static int set_udp_server(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context) 
+static int set_udp_server(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
 {
         int ret;
         unsigned int port;
         lml_log_source_t *ls;
         char *addr, source[512];
-        
-        if ( arg && *arg ) {                
+
+        if ( arg && *arg ) {
                 ret = prelude_parse_address(arg, &addr, &port);
                 if ( ret < 0 )
                         return ret;
@@ -419,49 +419,49 @@ static int set_udp_server(prelude_option_t *opt, const char *arg, prelude_string
         }
 
         snprintf(source, sizeof(source), "%s:%u/udp", addr, port);
-        
+
         ret = lml_log_source_new(&ls, context, source);
         if ( ret < 0 || ret == 1 ) {
                 free(addr);
                 return ret;
         }
-        
+
         ret = add_server(ls, addr, port);
         free(addr);
-        
+
         if ( ret < 0 )
                 return -1;
 
-        prelude_log(PRELUDE_LOG_INFO, "- Listening for syslog message on %s.\n", source);
-        
+        prelude_log(PRELUDE_LOG_INFO, "Listening for syslog message on %s.\n", source);
+
         return 0;
 }
 
 
 
-static int set_warning_limit(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context) 
+static int set_warning_limit(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
 {
         char *endptr;
-        
+
         config.warning_limit = strtol(arg, &endptr, 10);
         if ( *endptr != '\0' || config.warning_limit < -1 ) {
                 prelude_string_sprintf(err, "Invalid warning limit: %s", arg);
                 return -1;
         }
-        
+
         return 0;
 }
 
 
-static int set_format(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context) 
+static int set_format(prelude_option_t *opt, const char *arg, prelude_string_t *err, void *context)
 {
         lml_log_format_t *format;
         prelude_option_context_t *octx;
-        
+
         format = lml_log_format_new(arg);
         if ( ! format )
                 return -1;
-        
+
         return prelude_option_new_context(opt, &octx, arg, format);
 }
 
@@ -474,7 +474,7 @@ static int set_user(prelude_option_t *opt, const char *optarg, prelude_string_t
         struct passwd *pw;
 
         for ( p = optarg; isdigit((int) *p); p++ );
-        
+
         if ( *p == 0 )
                 uid = atoi(optarg);
         else {
@@ -488,7 +488,7 @@ static int set_user(prelude_option_t *opt, const char *optarg, prelude_string_t
         }
 
         config.wanted_uid = uid;
-        
+
         return 0;
 }
 
@@ -514,7 +514,7 @@ static int set_group(prelude_option_t *opt, const char *optarg, prelude_string_t
         }
 
         config.wanted_gid = gid;
-        
+
         return 0;
 }
 
@@ -531,11 +531,11 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
         config.warning_limit = -1;
         config.wanted_uid = getuid();
         config.wanted_gid = getgid();
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI, 'h', "help",
                            "Print this help", PRELUDE_OPTION_ARGUMENT_NONE, print_help, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI, 'v', "version",
                            "Print version number", PRELUDE_OPTION_ARGUMENT_NONE,
                            print_version, NULL);
@@ -544,24 +544,24 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
         prelude_option_add(ropt, NULL, PRELUDE_OPTION_TYPE_CFG|PRELUDE_OPTION_TYPE_CLI, 0, "user",
                            "Set the user ID used by prelude-lml", PRELUDE_OPTION_ARGUMENT_REQUIRED, set_user, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CFG|PRELUDE_OPTION_TYPE_CLI, 0, "group",
                            "Set the group ID used by prelude-lml", PRELUDE_OPTION_ARGUMENT_REQUIRED, set_group, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'q', "quiet",
                            "Quiet mode", PRELUDE_OPTION_ARGUMENT_NONE, set_quiet_mode, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'D', "debug-level",
                            "Debug mode", PRELUDE_OPTION_ARGUMENT_OPTIONAL, set_debug_mode, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'd', "daemon",
                            "Run in daemon mode", PRELUDE_OPTION_ARGUMENT_NONE,
                            set_daemon_mode, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_FIRST);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'P', "pidfile",
                            "Write Prelude LML PID to specified file",
                            PRELUDE_OPTION_ARGUMENT_REQUIRED, set_pidfile, NULL);
@@ -570,26 +570,26 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
         prelude_option_add(ropt, NULL, PRELUDE_OPTION_TYPE_CLI, 0, "text-output",
                            "Dump alert to stdout, or to the specified file", PRELUDE_OPTION_ARGUMENT_OPTIONAL,
                            set_text_output, NULL);
-        
+
         prelude_option_add(ropt, NULL, PRELUDE_OPTION_TYPE_CLI, 0, "dry-run",
                            "No alert emission / Prelude connection", PRELUDE_OPTION_ARGUMENT_NONE,
                            set_dry_run, NULL);
-        
+
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI, 'c', "config",
                            "Configuration file to use", PRELUDE_OPTION_ARGUMENT_REQUIRED,
                            set_conf_file, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-                                
+
         prelude_option_add(ropt, NULL, all_hook, 0, "max-rotation-time-offset",
                            "Specifies the maximum time difference, in seconds, between the time " \
                            "of logfiles rotation. If this amount is reached, a high "   \
                            "severity alert will be emited", PRELUDE_OPTION_ARGUMENT_REQUIRED,
                            set_rotation_time_offset, get_rotation_time_offset);
-        
+
         prelude_option_add(ropt, NULL, all_hook, 0, "max-rotation-size-offset",
                            "Specifies the maximum difference, in bytes, between two logfile "
                            "rotation. If this difference is reached, a high severity alert "
-                           "will be emited", PRELUDE_OPTION_ARGUMENT_REQUIRED, set_rotation_size_offset, 
+                           "will be emited", PRELUDE_OPTION_ARGUMENT_REQUIRED, set_rotation_size_offset,
                            get_rotation_size_offset);
 
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 0, "warning-limit",
@@ -597,7 +597,7 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
                            "-1 unlimited, or user defined number)", PRELUDE_OPTION_ARGUMENT_REQUIRED,
                            set_warning_limit, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_IMMEDIATE);
-        
+
         prelude_option_add(ropt, NULL, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 'b', "batch-mode",
                            "Tell LML to run in batch mode", PRELUDE_OPTION_ARGUMENT_NONE,
                            set_batch_mode, NULL);
@@ -613,39 +613,39 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
         prelude_option_add(ropt, &opt, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG,
                            0, "format", NULL, PRELUDE_OPTION_ARGUMENT_REQUIRED, set_format, NULL);
         prelude_option_set_priority(opt, PRELUDE_OPTION_PRIORITY_LAST);
-        
+
         prelude_option_add(opt, NULL, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG,
                            't', "time-format", "Specify the input timestamp format", PRELUDE_OPTION_ARGUMENT_REQUIRED,
                            set_logfile_ts_format, NULL);
-        
+
         prelude_option_add(opt, NULL, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG,
                            'p', "prefix-regex", "Specify the input prefix format", PRELUDE_OPTION_ARGUMENT_REQUIRED,
                            set_logfile_prefix_regex, NULL);
-        
+
         prelude_option_add(opt, NULL, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG,
                            'f', "file", "Specify a file to monitor (use \"-\" for standard input)",
                            PRELUDE_OPTION_ARGUMENT_REQUIRED, set_file, NULL);
-        
+
         prelude_option_add(opt, NULL, PRELUDE_OPTION_TYPE_CLI|PRELUDE_OPTION_TYPE_CFG, 's', "udp-server",
-                           "address:port pair to listen to syslog to UDP messages (default port 514)", 
+                           "address:port pair to listen to syslog to UDP messages (default port 514)",
                            PRELUDE_OPTION_ARGUMENT_OPTIONAL, set_udp_server, NULL);
-        
+
         ret = prelude_option_read(ropt, &config_file, &argc, argv, &err, NULL);
         if ( ret < 0 ) {
                 if ( prelude_error_get_code(ret) == PRELUDE_ERROR_EOF )
                         return -1;
-                
+
                 if ( err )
                         prelude_log(PRELUDE_LOG_WARN, "%s.\n", prelude_string_get_string(err));
                 else
                         prelude_perror(ret, "error processing options");
-                
+
                 return -1;
         }
 
         while ( ret < argc )
                 prelude_log(PRELUDE_LOG_WARN, "Unhandled command line argument: '%s'.\n", argv[ret++]);
-        
+
         if ( config.batch_mode && config.udp_nserver ) {
                 prelude_log(PRELUDE_LOG_WARN, "UDP server and batch modes can't be used together.\n");
                 return -1;
@@ -660,31 +660,31 @@ int lml_options_init(prelude_option_t *ropt, int argc, char **argv)
                 prelude_log(PRELUDE_LOG_WARN, "No file or UDP server available for monitoring: terminating.\n");
                 return -1;
         }
-        
+
         ret = drop_privilege();
         if ( ret < 0 )
                 return -1;
 
         if ( config.dry_run )
                 return 0;
-        
+
         ret = prelude_client_new(&config.lml_client, "prelude-lml");
         if ( ret < 0 ) {
-                prelude_perror(ret, "error creating prelude-client");                
+                prelude_perror(ret, "error creating prelude-client");
                 return -1;
         }
 
         prelude_client_set_config_filename(config.lml_client, config_file);
-        
+
         ret = lml_alert_init(config.lml_client);
         if ( ret < 0 )
                 return -1;
-        
+
         ret = prelude_client_start(config.lml_client);
         if ( ret < 0 ) {
                 prelude_perror(ret, "error starting prelude-client");
                 return -1;
         }
-        
+
         return 0;
 }
