@@ -6,7 +6,7 @@
 * This file is part of the Prelude-LML program.
 *
 * This program is free software; you can redistribute it and/or modify
-* it under the terms of the GNU General Public License as published by 
+* it under the terms of the GNU General Public License as published by
 * the Free Software Foundation; either version 2, or (at your option)
 * any later version.
 *
@@ -92,7 +92,7 @@ static void print_stats(const char *prefix, struct timeval *end)
         double tdiv;
 
         tdiv = (end->tv_sec + (double) end->tv_usec / 1000000) - (start.tv_sec + (double) start.tv_usec / 1000000);
-                
+
         prelude_log(PRELUDE_LOG_WARN, "%s%lu line processed in %.2f seconds (%.2f EPS), %lu alert emited.\n",
                     prefix, config.line_processed, tdiv, config.line_processed / tdiv, config.alert_count);
 }
@@ -101,26 +101,23 @@ static void print_stats(const char *prefix, struct timeval *end)
 
 static RETSIGTYPE sig_handler(int signum)
 {
-        got_signal = signum;      
+        got_signal = signum;
 }
 
 
-static void handle_signal(void)
+static void server_close(void)
 {
         size_t i;
-        
+
         for ( i = 0; i < config.udp_nserver; i++ )
                 udp_server_close(config.udp_server[i]);
-        
-        exit(2);
 }
 
 
-
 static void handle_sigquit(void)
 {
         struct timeval end;
-        
+
         gettimeofday(&end, NULL);
         print_stats("statistics signal received: ", &end);
 }
@@ -132,15 +129,15 @@ static const char *get_restart_string(void)
         int ret;
         size_t i;
         prelude_string_t *buf;
-        
+
         ret = prelude_string_new(&buf);
         if ( ret < 0 )
                 return global_argv[0];
-        
+
         for ( i = 0; global_argv[i] != NULL; i++ ) {
                 if ( ! prelude_string_is_empty(buf) )
                         prelude_string_cat(buf, " ");
-                        
+
                 prelude_string_cat(buf, global_argv[i]);
         }
 
@@ -148,23 +145,16 @@ static const char *get_restart_string(void)
 }
 
 
-static void handle_sighup(void) 
+static void handle_sighup(void)
 {
         int ret;
-        size_t i;
 
-        /*
-         * close the UDP server, so that we can bind the port again.
-         */
-        for ( i = 0; i < config.udp_nserver; i++ )
-                udp_server_close(config.udp_server[i]);
-        
         /*
          * Here we go !
          */
         ret = execvp(global_argv[0], global_argv);
         if ( ret < 0 ) {
-                prelude_log(PRELUDE_LOG_ERR, "error re-executing lml\n");
+                prelude_log(PRELUDE_LOG_ERR, "error restarting '%s': %s\n", global_argv[0], prelude_strerror(ret));
                 return;
         }
 }
@@ -174,33 +164,40 @@ static void handle_sighup(void)
 void _lml_handle_signal_if_needed(void)
 {
         int signo;
-        
+
         if ( ! got_signal )
                 return;
 
         signo = got_signal;
         got_signal = 0;
 
-        if ( signo == SIGHUP ) {
-                prelude_log(PRELUDE_LOG_WARN, "signal %d received, restarting (%s).\n", signo, get_restart_string());
-                handle_sighup();
-        }
-        
         if ( signo == SIGQUIT || signo == SIGUSR1 ) {
                 handle_sigquit();
                 return;
         }
-        
+
+        server_close();
+
+        if ( config.lml_client )
+                prelude_client_destroy(config.lml_client, PRELUDE_CLIENT_EXIT_STATUS_FAILURE);
+
+        prelude_deinit();
+
+        if ( signo == SIGHUP ) {
+                prelude_log(PRELUDE_LOG_WARN, "signal %d received, restarting (%s).\n", signo, get_restart_string());
+                handle_sighup();
+        }
+
         prelude_log(PRELUDE_LOG_WARN, "signal %d received, terminating prelude-lml.\n", signo);
-        handle_signal();
+        exit(2);
 }
 
 
 
-static void regex_match_cb(void *plugin, void *data) 
+static void regex_match_cb(void *plugin, void *data)
 {
         struct regex_data *rdata = data;
-        
+
         log_plugin_run(plugin, rdata->log_source, rdata->log_entry);
 }
 
@@ -221,18 +218,18 @@ void lml_dispatch_log(lml_log_source_t *ls, const char *str, size_t size)
 {
         struct regex_data rdata;
         lml_log_entry_t *log_entry;
-        
+
         prelude_log_debug(3, "[LOG] %s\n", str);
 
         log_entry = lml_log_entry_new();
         if ( ! log_entry )
                 return;
-        
+
         lml_log_entry_set_log(log_entry, ls, str, size);
 
         rdata.log_source = ls;
         rdata.log_entry = log_entry;
-        
+
         regex_exec(lml_log_source_get_regex_list(ls), &regex_match_cb, &rdata,
                    lml_log_entry_get_message(log_entry), lml_log_entry_get_message_len(log_entry));
 
@@ -241,61 +238,61 @@ void lml_dispatch_log(lml_log_source_t *ls, const char *str, size_t size)
 
 
 
-static void wait_for_event(void) 
+static void wait_for_event(void)
 {
         int ret;
         size_t i;
         fd_set fds;
         struct timeval tv, lstart, end;
         int file_event_fd, udp_event_fd, max = 0;
-        
+
         FD_ZERO(&fds);
 
-        file_event_fd = file_server_get_event_fd();        
+        file_event_fd = file_server_get_event_fd();
         if ( file_event_fd >= 0 ) {
                 max = file_event_fd;
                 FD_SET(file_event_fd, &fds);
         }
-        
+
         for ( i = 0; i < config.udp_nserver; i++ ) {
                 udp_event_fd = udp_server_get_event_fd(config.udp_server[i]);
-                
+
                 FD_SET(udp_event_fd, &fds);
                 max = MAX(max, udp_event_fd);
         }
 
         gettimeofday(&start, NULL);
         gettimeofday(&lstart, NULL);
-        
+
         while ( 1 ) {
                 _lml_handle_signal_if_needed();
-                
+
                 tv.tv_sec = 1;
                 tv.tv_usec = 0;
-                
+
                 ret = select(max + 1, &fds, NULL, NULL, &tv);
                 if ( ret < 0 ) {
                         if ( errno == EINTR )
                                 continue;
-                        
+
                         prelude_log(PRELUDE_LOG_ERR, "select returned an error: %s.\n", strerror(errno));
                         break;
                 }
-                
+
                 gettimeofday(&end, NULL);
-                
+
                 if ( ret == 0 || end.tv_sec - lstart.tv_sec >= 1 ) {
                         gettimeofday(&lstart, NULL);
                         prelude_timer_wake_up();
-                        
+
                         if ( file_event_fd < 0 )
                                 file_server_wake_up();
                 }
 
                 for ( i = 0; i < config.udp_nserver; i++ ) {
                         udp_event_fd = udp_server_get_event_fd(config.udp_server[i]);
-                        
-                        if ( FD_ISSET(udp_event_fd, &fds) ) 
+
+                        if ( FD_ISSET(udp_event_fd, &fds) )
                                 udp_server_process_event(config.udp_server[i]);
                         else
                                 FD_SET(udp_event_fd, &fds);
@@ -303,7 +300,7 @@ static void wait_for_event(void)
 
                 if ( file_event_fd < 0 )
                         continue;
-                
+
                 if ( FD_ISSET(file_event_fd, &fds) )
                         file_server_wake_up();
                 else
@@ -318,7 +315,7 @@ int main(int argc, char **argv)
         int ret;
         struct timeval end;
         struct sigaction action;
-        
+
         /*
          * make sure we ignore sighup until acceptable.
          */
@@ -326,26 +323,25 @@ int main(int argc, char **argv)
         action.sa_handler = SIG_IGN;
         sigemptyset(&action.sa_mask);
         sigaction(SIGHUP, &action, NULL);
-        
+
         memset(&start, 0, sizeof(start));
         memset(&end, 0, sizeof(end));
-        
+
         prelude_init(&argc, argv);
         global_argv = argv;
-        
+
         PRELUDE_PLUGIN_SET_PRELOADED_SYMBOLS();
-        
+
         ret = prelude_option_new_root(&lml_root_optlist);
         if ( ret < 0 )
                 return ret;
-        
+
         ret = log_plugins_init(LOG_PLUGIN_DIR, lml_root_optlist);
-        if (ret < 0) {
-                prelude_log(PRELUDE_LOG_WARN, "error initializing logs plugins.\n");
-                return -1;
-        }
-        prelude_log_debug(1, "- Initialized %d logs plugins.\n", ret);
-        
+        if (ret < 0)
+                return ret;
+
+        prelude_log_debug(1, "Initialized %d logs plugins.\n", ret);
+
         ret = lml_options_init(lml_root_optlist, argc, argv);
         if ( ret < 0 )
                 exit(1);
@@ -356,7 +352,7 @@ int main(int argc, char **argv)
         action.sa_flags = 0;
         sigemptyset(&action.sa_mask);
         action.sa_handler = sig_handler;
-        
+
 #ifdef SA_INTERRUPT
         action.sa_flags |= SA_INTERRUPT;
 #endif
@@ -368,7 +364,7 @@ int main(int argc, char **argv)
         sigaction(SIGUSR1, &action, NULL);
         sigaction(SIGQUIT, &action, NULL);
         sigaction(SIGHUP, &action, NULL);
-        
+
         file_server_start_monitoring();
 
         /*
@@ -380,20 +376,20 @@ int main(int argc, char **argv)
                 wait_for_event();
         else {
                 gettimeofday(&start, NULL);
-                
+
                 do {
                         _lml_handle_signal_if_needed();
                         ret = file_server_wake_up();
-                        
+
                         if ( ! config.batch_mode )
                                 sleep(1);
-                        
+
                         prelude_timer_wake_up();
-                        
+
                 } while ( ! config.batch_mode || ret > 0 );
 
                 gettimeofday(&end, NULL);
-                
+
                 /*
                  * only call prelude_client_destroy in case we are running in batch
                  * mode, causing an heartbeat to be sent to notice of a normal exit.
@@ -403,6 +399,7 @@ int main(int argc, char **argv)
 
                 print_stats("- ", &end);
         }
-        
+
+        prelude_deinit();
         return 0;
 }
